@@ -2,21 +2,20 @@
 #' Download Latest Station List Information and Update GSODR's Internal Database
 #'
 #' This function downloads the latest station list (isd-history.csv) from the
-#' NCEI FTP server and updates the data distributed with \code{GSODR} to the
+#' NCEI FTP server and updates the data distributed with \pkg{GSODR} to the
 #' latest stations available.  These data provide unique identifiers, country,
 #' state (if in US), latitude, longitude, elevation and when weather
 #' observations begin and end.  Stations with invalid latitude and longitude
 #' values will not be included.
 #'
 #' Care should be taken when using this function if reproducibility is necessary
-#' as different machines with the same version of \code{GSODR} can end up with
+#' as different machines with the same version of \pkg{GSODR} can end up with
 #' different versions of the isd_history.csv file internally.
 #'
 #' There is no need to use this unless you know that a station exists in the
-#' GSODR data that is not available in the database distributed with
-#' \code{\link{GSODR}}.
+#' GSODR data that is not available in the self-contained database.
 #'
-#' To directly access these data, use:
+#' To directly access these data, use: \cr
 #' \code{load(system.file("extdata", "isd_history.rda", package = "GSODR"))}
 #'
 #' @examples
@@ -24,7 +23,7 @@
 #' update_station_list()
 #' }
 #'
-#' @author Adam H Sparks, \email{adamhsparks@gmail.com}
+#' @author Adam H Sparks, \email{adamhsparks@@gmail.com}
 #' @export
 #'
 update_station_list <- function() {
@@ -58,17 +57,17 @@ update_station_list <- function() {
   new_isd_history[new_isd_history == -999] <- NA
   new_isd_history <-
     new_isd_history[new_isd_history$LAT != 0 &
-                      new_isd_history$LON != 0, ]
+                      new_isd_history$LON != 0,]
   new_isd_history <-
     new_isd_history[new_isd_history$LAT > -90 &
-                      new_isd_history$LAT < 90, ]
+                      new_isd_history$LAT < 90,]
   new_isd_history <-
     new_isd_history[new_isd_history$LON > -180 &
-                      new_isd_history$LON < 180, ]
+                      new_isd_history$LON < 180,]
   new_isd_history$STNID <-
     as.character(paste(new_isd_history$USAF, new_isd_history$WBAN, sep = "-"))
-  new_isd_history <- new_isd_history[!is.na(new_isd_history$LAT), ]
-  new_isd_history <- new_isd_history[!is.na(new_isd_history$LON), ]
+  new_isd_history <- new_isd_history[!is.na(new_isd_history$LAT),]
+  new_isd_history <- new_isd_history[!is.na(new_isd_history$LON),]
 
   # left join the old and new data
   isd_history <- dplyr::left_join(
@@ -91,6 +90,7 @@ update_station_list <- function() {
   )
 
   # overwrite the existing isd_history.rda file on disk
-  fname <- system.file("extdata", "isd_history.rda", package = "GSODR")
+  fname <-
+    system.file("extdata", "isd_history.rda", package = "GSODR")
   save(isd_history, file = fname, compress = "bzip2")
 }
